@@ -1,6 +1,6 @@
-var _curry3 = require('./internal/_curry3');
-var is = require('./is');
+var _curry3 = /*#__PURE__*/require('./internal/_curry3');
 
+var is = /*#__PURE__*/require('./is');
 
 /**
  * Returns `true` if the specified object property is of the given type;
@@ -22,6 +22,9 @@ var is = require('./is');
  *      R.propIs(Number, 'x', {x: 'foo'});    //=> false
  *      R.propIs(Number, 'x', {});            //=> false
  */
-module.exports = _curry3(function propIs(type, name, obj) {
+
+
+var propIs = /*#__PURE__*/_curry3(function propIs(type, name, obj) {
   return is(type, obj[name]);
 });
+module.exports = propIs;
\ No newline at end of file
