@@ -1,5 +1,4 @@
-var _curry1 = require('./internal/_curry1');
-
+var _curry1 = /*#__PURE__*/require('./internal/_curry1');
 
 /**
  * Converts an object into an array of key, value arrays. The object's own
@@ -17,15 +16,18 @@ var _curry1 = require('./internal/_curry1');
  *         and prototype properties.
  * @example
  *
- *      var F = function() { this.x = 'X'; };
+ *      const F = function() { this.x = 'X'; };
  *      F.prototype.y = 'Y';
- *      var f = new F();
+ *      const f = new F();
  *      R.toPairsIn(f); //=> [['x','X'], ['y','Y']]
  */
-module.exports = _curry1(function toPairsIn(obj) {
+
+
+var toPairsIn = /*#__PURE__*/_curry1(function toPairsIn(obj) {
   var pairs = [];
   for (var prop in obj) {
     pairs[pairs.length] = [prop, obj[prop]];
   }
   return pairs;
 });
+module.exports = toPairsIn;
\ No newline at end of file
